=======
Section
=======

The Section commands are used to create sections and profiles with their associated properties and behavior. The various section objects are all derived from the Section object. The various profile objects are all derived from the Profile object. See Property commands for the property assignment commands.

.. toctree::
   :maxdepth: 1
   :caption: Objects in Section

   section/connector


Create sections
---------------

In Mdb
~~~~~~

.. autoclass:: abaqus.Section.SectionModel.SectionModel
    :members:

    .. autoclasstoc::


In Odb
~~~~~~

.. autoclass:: abaqus.Section.SectionOdb.SectionOdb
    :members:

    .. autoclasstoc::


Object features
---------------

Section
~~~~~~~

.. autoclass:: abaqus.Section.Section.Section
    :members:
    :inherited-members:

    .. autoclasstoc::

SectionBase
~~~~~~~~~~~

.. autoclass:: abaqus.Section.SectionBase.SectionBase
    :members:

    .. autoclasstoc::

AcousticInfiniteSection
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.AcousticInfiniteSection.AcousticInfiniteSection
    :members:

    .. autoclasstoc::

AcousticInterfaceSection
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.AcousticInterfaceSection.AcousticInterfaceSection
    :members:

    .. autoclasstoc::

BeamSection
~~~~~~~~~~~

.. autoclass:: abaqus.Section.BeamSection.BeamSection
    :members:

    .. autoclasstoc::

CohesiveSection
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.CohesiveSection.CohesiveSection
    :members:

    .. autoclasstoc::

CompositeShellSection
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.CompositeShellSection.CompositeShellSection
    :members:

    .. autoclasstoc::

CompositeSolidSection
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.CompositeSolidSection.CompositeSolidSection
    :members:

    .. autoclasstoc::

ConnectorSection
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.ConnectorSection.ConnectorSection
    :members:

    .. autoclasstoc::

EulerianSection
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.EulerianSection.EulerianSection
    :members:

    .. autoclasstoc::

GasketSection
~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.GasketSection.GasketSection
    :members:

    .. autoclasstoc::

GeneralStiffnessSection
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.GeneralStiffnessSection.GeneralStiffnessSection
    :members:

    .. autoclasstoc::

GeometryShellSection
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.GeometryShellSection.GeometryShellSection
    :members:

    .. autoclasstoc::

HomogeneousShellSection
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.HomogeneousShellSection.HomogeneousShellSection
    :members:

    .. autoclasstoc::

HomogeneousSolidSection
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.HomogeneousSolidSection.HomogeneousSolidSection
    :members:

    .. autoclasstoc::

LayerProperties
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.LayerProperties.LayerProperties
    :members:

    .. autoclasstoc::

LayerPropertiesArray
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.LayerPropertiesArray.LayerPropertiesArray
    :members:

    .. autoclasstoc::

MembraneSection
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.MembraneSection.MembraneSection
    :members:

    .. autoclasstoc::

MPCSection
~~~~~~~~~~

.. autoclass:: abaqus.Section.MPCSection.MPCSection
    :members:

    .. autoclasstoc::

PEGSection
~~~~~~~~~~

.. autoclass:: abaqus.Section.PEGSection.PEGSection
    :members:

    .. autoclasstoc::

RebarLayers
~~~~~~~~~~~

.. autoclass:: abaqus.Section.RebarLayers.RebarLayers
    :members:

    .. autoclasstoc::

SectionLayer
~~~~~~~~~~~~

.. autoclass:: abaqus.Section.SectionLayer.SectionLayer
    :members:

    .. autoclasstoc::

SectionLayerArray
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.SectionLayerArray.SectionLayerArray
    :members:

    .. autoclasstoc::

ShellSection
~~~~~~~~~~~~

.. autoclass:: abaqus.Section.ShellSection.ShellSection
    :members:

    .. autoclasstoc::

SolidSection
~~~~~~~~~~~~

.. autoclass:: abaqus.Section.SolidSection.SolidSection
    :members:

    .. autoclasstoc::

SurfaceSection
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.SurfaceSection.SurfaceSection
    :members:

    .. autoclasstoc::

TransverseShearBeam
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.TransverseShearBeam.TransverseShearBeam
    :members:

    .. autoclasstoc::

TransverseShearShell
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Section.TransverseShearShell.TransverseShearShell
    :members:

    .. autoclasstoc::

TrussSection
~~~~~~~~~~~~

.. autoclass:: abaqus.Section.TrussSection.TrussSection
    :members:

    .. autoclasstoc::

